==> katscript-jupyterlab-0.4.1.tgz: package/lib/codemirror-katscript-types.js <==
export const commands = [
    'opt_rf_readout_phase',
    'propagate_beam_astig',
    'frequency_response',
    'sensing_matrix_dc',
    'noise_projection',
    'print_model_attr',
    'noise_analysis',
    'propagate_beam',
    'print_model',
    'beam_trace',
    'run_locks',
    'freqresp',
    'parallel',
    'noxaxis',
    'change',
    'intrix',
    'lambda',
    'series',
    'x2axis',
    'x3axis',
    'debug',
    'modes',
    'print',
    'sweep',
    'xaxis',
    'abcd',
    'fsig',
    'link',
    'plot',
    'tem',
];
export const elements = [
    'quantum_shot_noise_detector_demod_1',
    'quantum_shot_noise_detector_demod_2',
    'quantum_noise_detector_demod_1',
    'quantum_noise_detector_demod_2',
    'quantum_shot_noise_detector',
    'directional_beam_splitter',
    'beam_property_detector',
    'power_detector_demod_1',
    'power_detector_demod_2',
    'quantum_noise_detector',
    'amplitude_detector',
    'degree_of_freedom',
    'power_detector_dc',
    'optical_bandpass',
    'signal_generator',
    'motion_detector',
    'readout_dc_qpd',
    'beam_splitter',
    'filter_butter',
    'filter_cheby1',
    'zpk_actuator',
    'ligo_triple',
    'filter_zpk',
    'readout_dc',
    'readout_rf',
    'amplifier',
    'free_mass',
    'ligo_quad',
    'modulator',
    'actuator',
    'isolator',
    'pendulum',
    'qnoised1',
    'qnoised2',
    'squeezer',
    'variable',
    'ccdline',
    'nothing',
    'qnoised',
    'splitpd',
    'astigd',
    'butter',
    'cavity',
    'cheby1',
    'mirror',
    'qshot1',
    'qshot2',
    'ccdpx',
    'fline',
    'gauss',
    'laser',
    'noise',
    'qshot',
    'space',
    'fcam',
    'gouy',
    'isol',
    'knmd',
    'lens',
    'lock',
    'sgen',
    'amp',
    'cav',
    'ccd',
    'dbs',
    'dof',
    'fpx',
    'mmd',
    'mod',
    'obp',
    'pd1',
    'pd2',
    'var',
    'zpk',
    'ad',
    'bp',
    'bs',
    'cp',
    'pd',
    'sq',
    'xd',
    'l',
    'm',
    's',
];
export const functions = [
    'geomspace',
    'linspace',
    'logspace',
    'arctan2',
    'deg2rad',
    'degrees',
    'rad2deg',
    'radians',
    'arccos',
    'arcsin',
    'conj',
    'imag',
    'real',
    'sqrt',
    'abs',
    'cos',
    'exp',
    'neg',
    'pos',
    'sin',
    'tan',
];
export const keywords = [
    'resolution',
    'stability',
    'bandpass',
    'bandstop',
    'highpass',
    'finesse',
    'lowpass',
    'modesep',
    'length',
    'xsplit',
    'ysplit',
    'abcd',
    'even',
    'fwhm',
    'gouy',
    'loss',
    'none',
    'pole',
    'div',
    'fsr',
    'lin',
    'log',
    'odd',
    'off',
    'tau',
    'am',
    'c0',
    'pi',
    'pm',
    'rc',
    'w0',
    'zr',
    'g',
    'l',
    'q',
    's',
    'w',
    'x',
    'y',
    'z',
];
export const operators = ['/', '*', '+', '&', '-'];

==> katscript-jupyterlab-0.4.5.tgz: package/lib/codemirror-katscript-types.js <==
export const commands = ['opt_rf_readout_phase',
    'propagate_beam_astig',
    'frequency_response',
    'sensing_matrix_dc',
    'noise_projection',
    'print_model_attr',
    'noise_analysis',
    'propagate_beam',
    'print_model',
    'beam_trace',
    'run_locks',
    'freqresp',
    'parallel',
    'noxaxis',
    'change',
    'intrix',
    'lambda',
    'series',
    'x2axis',
    'x3axis',
    'debug',
    'modes',
    'print',
    'sweep',
    'xaxis',
    'abcd',
    'fsig',
    'link',
    'plot',
    'tem'];
export const elements = ['quantum_shot_noise_detector_demod_1',
    'quantum_shot_noise_detector_demod_2',
    'quantum_noise_detector_demod_1',
    'quantum_noise_detector_demod_2',
    'quantum_shot_noise_detector',
    'directional_beamsplitter',
    'beam_property_detector',
    'power_detector_demod_1',
    'power_detector_demod_2',
    'quantum_noise_detector',
    'amplitude_detector',
    'degree_of_freedom',
    'power_detector_dc',
    'optical_bandpass',
    'signal_generator',
    'motion_detector',
    'readout_dc_qpd',
    'filter_butter',
    'filter_cheby1',
    'beamsplitter',
    'zpk_actuator',
    'ligo_triple',
    'filter_zpk',
    'readout_dc',
    'readout_rf',
    'amplifier',
    'free_mass',
    'ligo_quad',
    'modulator',
    'actuator',
    'isolator',
    'pendulum',
    'qnoised1',
    'qnoised2',
    'squeezer',
    'variable',
    'ccdline',
    'nothing',
    'qnoised',
    'splitpd',
    'astigd',
    'butter',
    'cavity',
    'cheby1',
    'mirror',
    'qshot1',
    'qshot2',
    'ccdpx',
    'fline',
    'gauss',
    'laser',
    'noise',
    'qshot',
    'space',
    'fcam',
    'gouy',
    'isol',
    'knmd',
    'lens',
    'lock',
    'sgen',
    'amp',
    'cav',
    'ccd',
    'dbs',
    'dof',
    'fpx',
    'mmd',
    'mod',
    'obp',
    'pd1',
    'pd2',
    'var',
    'zpk',
    'ad',
    'bp',
    'bs',
    'cp',
    'pd',
    'sq',
    'xd',
    'l',
    'm',
    's'];
export const functions = ['geomspace',
    'linspace',
    'logspace',
    'arctan2',
    'deg2rad',
    'degrees',
    'rad2deg',
    'radians',
    'arccos',
    'arcsin',
    'conj',
    'imag',
    'real',
    'sqrt',
    'abs',
    'cos',
    'exp',
    'neg',
    'pos',
    'sin',
    'tan'];
export const keywords = ['resolution',
    'stability',
    'bandpass',
    'bandstop',
    'highpass',
    'finesse',
    'lowpass',
    'modesep',
    'length',
    'xsplit',
    'ysplit',
    'abcd',
    'even',
    'fwhm',
    'gouy',
    'loss',
    'none',
    'pole',
    'div',
    'fsr',
    'lin',
    'log',
    'odd',
    'off',
    'tau',
    'am',
    'c0',
    'pi',
    'pm',
    'rc',
    'w0',
    'zr',
    'g',
    'l',
    'q',
    's',
    'w',
    'x',
    'y',
    'z'];
export const operators = ['+', '/', '*', '&', '-'];
